aboutsummaryrefslogtreecommitdiffstats
path: root/Demos/Host/MassStorageHost
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2009-05-06 07:50:34 +0000
committerDean Camera <dean@fourwalledcubicle.com>2009-05-06 07:50:34 +0000
commit63a8f66d92b5d7018a4d962f4f7b23774a621771 (patch)
tree49359656bc06962f6508e5896551343842461e36 /Demos/Host/MassStorageHost
parentf11f69fd2989899b3088ea7d11b981f2d68c05e0 (diff)
downloadlufa-63a8f66d92b5d7018a4d962f4f7b23774a621771.tar.gz
lufa-63a8f66d92b5d7018a4d962f4f7b23774a621771.tar.bz2
lufa-63a8f66d92b5d7018a4d962f4f7b23774a621771.zip
Changed HWB board driver to Buttons driver, to allow for the support of future boards with more than one mounted GPIO button.
Diffstat (limited to 'Demos/Host/MassStorageHost')
-rw-r--r--Demos/Host/MassStorageHost/MassStorageHost.c8
-rw-r--r--Demos/Host/MassStorageHost/MassStorageHost.h2
2 files changed, 5 insertions, 5 deletions
diff --git a/Demos/Host/MassStorageHost/MassStorageHost.h b/Demos/Host/MassStorageHost/MassStorageHost.h
index d4b9947bb..216065970 100644
--- a/Demos/Host/MassStorageHost/MassStorageHost.h
+++ b/Demos/Host/MassStorageHost/MassStorageHost.h
@@ -52,7 +52,7 @@
#include <LUFA/Drivers/USB/USB.h> // USB Functionality
#include <LUFA/Drivers/Peripheral/SerialStream.h> // Serial stream driver
#include <LUFA/Drivers/Board/LEDs.h> // LEDs driver
- #include <LUFA/Drivers/Board/HWB.h> // Hardware Button driver
+ #include <LUFA/Drivers/Board/Buttons.h> // Board Buttons driver
#include <LUFA/Scheduler/Scheduler.h> // Simple scheduler for task management
/* Enums: */
diff --git a/Demos/Host/MassStorageHost/MassStorageHost.c b/Demos/Host/MassStorageHost/MassStorageHost.c
index 15006d336..d06e3a63a 100644
--- a/Demos/Host/MassStorageHost/MassStorageHost.c
+++ b/Demos/Host/MassStorageHost/MassStorageHost.c
@@ -63,7 +63,7 @@ int main(void)
/* Hardware Initialization */
SerialStream_Init(9600, false);
LEDs_Init();
- HWB_Init();
+ Buttons_Init();
/* Indicate USB not ready */
UpdateStatus(Status_USBNotReady);
@@ -319,10 +319,10 @@ TASK(USB_MassStore_Host)
puts_P(PSTR("\r\n"));
}
- puts_P(PSTR("\r\n\r\nPress HWB to read entire ASCII contents of disk...\r\n\r\n"));
+ puts_P(PSTR("\r\n\r\nPress board button to read entire ASCII contents of disk...\r\n\r\n"));
- /* Wait for HWB to be pressed */
- while (!(HWB_GetStatus()))
+ /* Wait for the board button to be pressed */
+ while (!(Buttons_GetStatus() & BUTTONS_BUTTON1))
{
/* Abort if device removed */
if (!(USB_IsConnected))